@@ -45,7 +45,7 @@ class Server(uvicorn.Server):
         self.thread.join()
 
 
-def get_first_available_port(initial: int, final: int) -> int:
+def get_first_available_port(initial: int, final: int, reuse_port: bool = False) -> int:
     """
     Gets the first open port in a specified range of port numbers
     Parameters:
@@ -57,6 +57,8 @@ def get_first_available_port(initial: int, final: int) -> int:
     for port in range(initial, final):
         try:
             s = socket.socket()  # create a socket object
+            if reuse_port:
+                s.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
             s.bind((LOCALHOST_NAME, port))  # Bind to the port
             s.close()
             return port
