@@ -1,10 +1,16 @@
 import asyncio
+import io
 import random
+import sys
 import time
 import unittest
+import unittest.mock as mock
+from contextlib import contextmanager
 from unittest.mock import patch
 
+import mlflow
 import pytest
+import wandb
 
 import gradio as gr
 from gradio.routes import PredictBody
@@ -14,6 +20,17 @@ from gradio.utils import assert_configs_are_equivalent_besides_ids
 pytest_plugins = ("pytest_asyncio",)
 
 
+@contextmanager
+def captured_output():
+    new_out, new_err = io.StringIO(), io.StringIO()
+    old_out, old_err = sys.stdout, sys.stderr
+    try:
+        sys.stdout, sys.stderr = new_out, new_err
+        yield sys.stdout, sys.stderr
+    finally:
+        sys.stdout, sys.stderr = old_out, old_err
+
+
 class TestBlocks(unittest.TestCase):
     maxDiff = None
 
@@ -123,6 +140,62 @@ class TestBlocks(unittest.TestCase):
             assert difference >= 0.01
             assert result
 
+    def test_integration_wandb(self):
+        with captured_output() as (out, err):
+            wandb.log = mock.MagicMock()
+            wandb.Html = mock.MagicMock()
+            demo = gr.Blocks()
+            with demo:
+                gr.Textbox("Hi there!")
+            demo.integrate(wandb=wandb)
+
+            self.assertEqual(
+                out.getvalue().strip(),
+                "The WandB integration requires you to `launch(share=True)` first.",
+            )
+            demo.share_url = "tmp"
+            demo.integrate(wandb=wandb)
+            wandb.log.assert_called_once()
+
+    @mock.patch("comet_ml.Experiment")
+    def test_integration_comet(self, mock_experiment):
+        experiment = mock_experiment()
+        experiment.log_text = mock.MagicMock()
+        experiment.log_other = mock.MagicMock()
+
+        demo = gr.Blocks()
+        with demo:
+            gr.Textbox("Hi there!")
+
+        demo.launch(prevent_thread_lock=True)
+        demo.integrate(comet_ml=experiment)
+        experiment.log_text.assert_called_with("gradio: " + demo.local_url)
+        demo.share_url = "tmp"  # used to avoid creating real share links.
+        demo.integrate(comet_ml=experiment)
+        experiment.log_text.assert_called_with("gradio: " + demo.share_url)
+        self.assertEqual(experiment.log_other.call_count, 2)
+        demo.share_url = None
+        demo.close()
+
+    def test_integration_mlflow(self):
+        mlflow.log_param = mock.MagicMock()
+        demo = gr.Blocks()
+        with demo:
+            gr.Textbox("Hi there!")
+
+        demo.launch(prevent_thread_lock=True)
+        demo.integrate(mlflow=mlflow)
+        mlflow.log_param.assert_called_with(
+            "Gradio Interface Local Link", demo.local_url
+        )
+        demo.share_url = "tmp"  # used to avoid creating real share links.
+        demo.integrate(mlflow=mlflow)
+        mlflow.log_param.assert_called_with(
+            "Gradio Interface Share Link", demo.share_url
+        )
+        demo.share_url = None
+        demo.close()
+
 
 if __name__ == "__main__":
     unittest.main()
